@@ -13,9 +13,8 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.1.3
+v1.1.4
 dpt_settings/__init__.py
 """
 
-from .environment_dict import EnvironmentDict
-from .settings import Settings
+from dpt_runtime import EnvironmentDict, Settings
